/* Modified from FreeBSD 2.1 sys/i386/boot/netboot */
/**************************************************************************
NETBOOT -  BOOTP/TFTP Bootstrap Program

Author: Martin Renters
  Date: Dec/93

**************************************************************************/

#include <oskit/machine/types.h>
#include <oskit/c/sys/types.h>
#include "boot.h"			/* struct kerninfo */

#ifndef MAX_ARP_RETRIES
#define MAX_ARP_RETRIES		20
#endif

#ifndef MAX_RPC_RETRIES
#define MAX_RPC_RETRIES		5
#endif

#ifndef TIMEOUT
#define TIMEOUT			20
#endif

#define IP_BROADCAST	0xFFFFFFFF
#define NFS_READ_SIZE	1024


/*
 * Random crap.
 */

#define MKIP(a,b,c,d) (((a)<<24) | ((b)<<16) | ((c)<<8) | (d))

void convert_ipaddr(void *d, void *s);
char *netsprintf(char *buf, char *fmt, ...);
void netprintf(char *fmt, ...);
int parse_cmdline(char *cmdline, int cmdsize, unsigned int *ip, char **dir,
		  char **name, char **rest);
